# Changelog

## 0.7.0 (2025-07-19)

Full Changelog: [v0.6.0...v0.7.0](https://github.com/The-Swarm-Corporation/swarms-sdk/compare/v0.6.0...v0.7.0)

### Features

* **api:** api update ([200cef5](https://github.com/The-Swarm-Corporation/swarms-sdk/commit/200cef5f553ddeec1c1275693f5879de7e679cdb))

## 0.6.0 (2025-07-15)

Full Changelog: [v0.5.0...v0.6.0](https://github.com/The-Swarm-Corporation/swarms-sdk/compare/v0.5.0...v0.6.0)

### Features

* clean up environment call outs ([b30938f](https://github.com/The-Swarm-Corporation/swarms-sdk/commit/b30938f43c02bb38eab11e50742cc27af6052092))

## 0.5.0 (2025-07-13)

Full Changelog: [v0.4.0...v0.5.0](https://github.com/The-Swarm-Corporation/swarms-sdk/compare/v0.4.0...v0.5.0)

### Features

* **api:** api update ([10c1705](https://github.com/The-Swarm-Corporation/swarms-sdk/commit/10c170540f52cd99f60b7e4aa0c3115954cec60e))

## 0.4.0 (2025-07-13)

Full Changelog: [v0.3.0...v0.4.0](https://github.com/The-Swarm-Corporation/swarms-sdk/compare/v0.3.0...v0.4.0)

### Features

* **api:** api update ([c05496b](https://github.com/The-Swarm-Corporation/swarms-sdk/commit/c05496bf3d71e50b14ece2db908b39a80dd4c20e))


### Bug Fixes

* **client:** don't send Content-Type header on GET requests ([779c6b6](https://github.com/The-Swarm-Corporation/swarms-sdk/commit/779c6b6e2e5a689cd8c773db79b0b53613fc13d9))
* **parsing:** correctly handle nested discriminated unions ([998f51b](https://github.com/The-Swarm-Corporation/swarms-sdk/commit/998f51baa69470143e3b43041f18f4e34e9a8ef6))


### Chores

* configure new SDK language ([0b77958](https://github.com/The-Swarm-Corporation/swarms-sdk/commit/0b779588ef5f414dc958097e1c47ab457eaca5c6))
* **internal:** bump pinned h11 dep ([05d9703](https://github.com/The-Swarm-Corporation/swarms-sdk/commit/05d97034f7de4d87752e53552731abf1fbc31b12))
* **package:** mark python 3.13 as supported ([598580a](https://github.com/The-Swarm-Corporation/swarms-sdk/commit/598580ab8bd50951cd1a57e7e62ea759dedc4246))
* **readme:** fix version rendering on pypi ([22731a7](https://github.com/The-Swarm-Corporation/swarms-sdk/commit/22731a7a3f32f1d56257c290ad0d758ef1950a45))

## 0.3.0 (2025-07-04)

Full Changelog: [v0.2.0...v0.3.0](https://github.com/The-Swarm-Corporation/swarms-sdk/compare/v0.2.0...v0.3.0)

### Features

* **api:** /v1/ratelimits ([4405997](https://github.com/The-Swarm-Corporation/swarms-sdk/commit/4405997499ef214898b6c52633226629c4592856))
* **api:** api update ([1d35a30](https://github.com/The-Swarm-Corporation/swarms-sdk/commit/1d35a30e5800ac89bf89355a0c781df082dd270a))


### Chores

* update SDK settings ([90ae048](https://github.com/The-Swarm-Corporation/swarms-sdk/commit/90ae048a61f0d9c62ce251febad3e9666580f66f))

## 0.2.0 (2025-07-03)

Full Changelog: [v0.1.8...v0.2.0](https://github.com/The-Swarm-Corporation/swarms-sdk/compare/v0.1.8...v0.2.0)

### Features

* **api:** api key fix ([7515bca](https://github.com/The-Swarm-Corporation/swarms-sdk/commit/7515bcad6ea549008901dbb187d736b3a996b812))
* **api:** fix stainless.yml ([6a102e3](https://github.com/The-Swarm-Corporation/swarms-sdk/commit/6a102e3dedae261e65ce7a383cec76cb0737ab46))

## 0.1.8 (2025-07-03)

Full Changelog: [v0.1.7...v0.1.8](https://github.com/The-Swarm-Corporation/swarms-sdk/compare/v0.1.7...v0.1.8)

### Chores

* sync repo ([f789c08](https://github.com/The-Swarm-Corporation/swarms-sdk/commit/f789c08eeb01cbbd6a2be8f70f341c99d362fb22))
* update SDK settings ([07b018a](https://github.com/The-Swarm-Corporation/swarms-sdk/commit/07b018af809179258493151a1d0175d4651f65e6))
* update SDK settings ([07a3fff](https://github.com/The-Swarm-Corporation/swarms-sdk/commit/07a3fff84c29b9f2d2f40a3205ff4e92b45dbbdf))
